/*
 * Copyright 2009 Prime Technology.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.primefaces.component.hotkey;

import javax.faces.webapp.UIComponentELTag;
import javax.faces.component.UIComponent;

public class HotkeyTag extends UIComponentELTag {

	private javax.el.MethodExpression _actionListener;
	private javax.el.MethodExpression _action;
	private javax.el.ValueExpression _immediate;
	private javax.el.ValueExpression _bind;
	private javax.el.ValueExpression _update;
	private javax.el.ValueExpression _handler;
	private javax.el.ValueExpression _partialSubmit;
	private javax.el.ValueExpression _onstart;
	private javax.el.ValueExpression _oncomplete;

	public void release(){
		super.release();
		this._actionListener = null;
		this._action = null;
		this._immediate = null;
		this._bind = null;
		this._update = null;
		this._handler = null;
		this._partialSubmit = null;
		this._onstart = null;
		this._oncomplete = null;
	}

	protected void setProperties(UIComponent comp){
		super.setProperties(comp);

		org.primefaces.component.hotkey.Hotkey component = null;
		try {
			component = (org.primefaces.component.hotkey.Hotkey) comp;
		} catch(ClassCastException cce) {
			throw new IllegalStateException("Component " + component.toString() + " not expected type.");
		}

		if(_actionListener != null) {
			component.addActionListener(new javax.faces.event.MethodExpressionActionListener(_actionListener));
		}
		if(_action != null) {
			component.setActionExpression(_action);
		}
		if(_immediate != null) {
			component.setValueExpression("immediate", _immediate);
		}
		if(_bind != null) {
			component.setValueExpression("bind", _bind);
		}
		if(_update != null) {
			component.setValueExpression("update", _update);
		}
		if(_handler != null) {
			component.setValueExpression("handler", _handler);
		}
		if(_partialSubmit != null) {
			component.setValueExpression("partialSubmit", _partialSubmit);
		}
		if(_onstart != null) {
			component.setValueExpression("onstart", _onstart);
		}
		if(_oncomplete != null) {
			component.setValueExpression("oncomplete", _oncomplete);
		}
	}

	public String getComponentType() {
		return Hotkey.COMPONENT_TYPE;
	}

	public String getRendererType() {
		return "org.primefaces.component.HotkeyRenderer";
	}

	public void setActionListener(javax.el.MethodExpression expression){
		this._actionListener = expression;
	}

	public void setAction(javax.el.MethodExpression expression){
		this._action = expression;
	}

	public void setImmediate(javax.el.ValueExpression expression){
		this._immediate = expression;
	}

	public void setBind(javax.el.ValueExpression expression){
		this._bind = expression;
	}

	public void setUpdate(javax.el.ValueExpression expression){
		this._update = expression;
	}

	public void setHandler(javax.el.ValueExpression expression){
		this._handler = expression;
	}

	public void setPartialSubmit(javax.el.ValueExpression expression){
		this._partialSubmit = expression;
	}

	public void setOnstart(javax.el.ValueExpression expression){
		this._onstart = expression;
	}

	public void setOncomplete(javax.el.ValueExpression expression){
		this._oncomplete = expression;
	}

}