/*
 * Copyright 2009 Prime Technology.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.primefaces.component.tree;

import javax.faces.component.UIComponentBase;
import javax.faces.context.FacesContext;
import javax.el.ValueExpression;
import javax.el.MethodExpression;
import javax.faces.render.Renderer;
import java.io.IOException;
import org.primefaces.resource.ResourceHolder;
import org.primefaces.renderkit.PartialRenderer;
import org.primefaces.component.api.AjaxComponent;
import org.primefaces.event.NodeSelectEvent;
import org.primefaces.event.NodeExpandEvent;
import org.primefaces.event.NodeCollapseEvent;

public class Tree extends UIComponentBase implements AjaxComponent {


	public static final String COMPONENT_TYPE = "org.primefaces.component.Tree";
	public static final String COMPONENT_FAMILY = "org.primefaces.component";
	private static final String DEFAULT_RENDERER = "org.primefaces.component.TreeRenderer";

	private java.lang.String _widgetVar;
	private java.lang.Object _value;
	private java.lang.String _toggleMode;
	private java.lang.Boolean _cache;
	private java.lang.String _expandAnim;
	private java.lang.String _collapseAnim;
	private javax.el.MethodExpression _nodeSelectListener;
	private javax.el.MethodExpression _nodeExpandListener;
	private javax.el.MethodExpression _nodeCollapseListener;
	private java.lang.String _onNodeClick;
	private java.lang.Boolean _expanded;

	public Tree() {
		setRendererType(DEFAULT_RENDERER);
		ResourceHolder resourceHolder = getResourceHolder();
		if(resourceHolder != null) {
			resourceHolder.addResource("/yui/treeview/assets/skins/sam/treeview.css");
			resourceHolder.addResource("/yui/utilities/utilities.js");
			resourceHolder.addResource("/jquery/jquery.js");
			resourceHolder.addResource("/primefaces/ajax/ajax.js");
			resourceHolder.addResource("/yui/treeview/treeview-min.js");
			resourceHolder.addResource("/primefaces/treeview/treeview.js");
		}
	}

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	public java.lang.String getWidgetVar() {
		if(_widgetVar != null )
			return _widgetVar;

		ValueExpression ve = getValueExpression("widgetVar");
		return ve != null ? (java.lang.String) ve.getValue(getFacesContext().getELContext())  : null;
	}
	public void setWidgetVar(java.lang.String _widgetVar) {
		this._widgetVar = _widgetVar;
	}

	public java.lang.Object getValue() {
		if(_value != null )
			return _value;

		ValueExpression ve = getValueExpression("value");
		return ve != null ? (java.lang.Object) ve.getValue(getFacesContext().getELContext())  : null;
	}
	public void setValue(java.lang.Object _value) {
		this._value = _value;
	}

	public java.lang.String getToggleMode() {
		if(_toggleMode != null )
			return _toggleMode;

		ValueExpression ve = getValueExpression("toggleMode");
		return ve != null ? (java.lang.String) ve.getValue(getFacesContext().getELContext())  : "async";
	}
	public void setToggleMode(java.lang.String _toggleMode) {
		this._toggleMode = _toggleMode;
	}

	public boolean isCache() {
		if(_cache != null )
			return _cache;

		ValueExpression ve = getValueExpression("cache");
		return ve != null ? (java.lang.Boolean) ve.getValue(getFacesContext().getELContext())  : true;
	}
	public void setCache(boolean _cache) {
		this._cache = _cache;
	}

	public java.lang.String getExpandAnim() {
		if(_expandAnim != null )
			return _expandAnim;

		ValueExpression ve = getValueExpression("expandAnim");
		return ve != null ? (java.lang.String) ve.getValue(getFacesContext().getELContext())  : null;
	}
	public void setExpandAnim(java.lang.String _expandAnim) {
		this._expandAnim = _expandAnim;
	}

	public java.lang.String getCollapseAnim() {
		if(_collapseAnim != null )
			return _collapseAnim;

		ValueExpression ve = getValueExpression("collapseAnim");
		return ve != null ? (java.lang.String) ve.getValue(getFacesContext().getELContext())  : null;
	}
	public void setCollapseAnim(java.lang.String _collapseAnim) {
		this._collapseAnim = _collapseAnim;
	}

	public javax.el.MethodExpression getNodeSelectListener() {
		return this._nodeSelectListener;
	}

	public void setNodeSelectListener(javax.el.MethodExpression _nodeSelectListener) {
		this._nodeSelectListener = _nodeSelectListener;
	}
	public javax.el.MethodExpression getNodeExpandListener() {
		return this._nodeExpandListener;
	}

	public void setNodeExpandListener(javax.el.MethodExpression _nodeExpandListener) {
		this._nodeExpandListener = _nodeExpandListener;
	}
	public javax.el.MethodExpression getNodeCollapseListener() {
		return this._nodeCollapseListener;
	}

	public void setNodeCollapseListener(javax.el.MethodExpression _nodeCollapseListener) {
		this._nodeCollapseListener = _nodeCollapseListener;
	}
	public java.lang.String getOnNodeClick() {
		if(_onNodeClick != null )
			return _onNodeClick;

		ValueExpression ve = getValueExpression("onNodeClick");
		return ve != null ? (java.lang.String) ve.getValue(getFacesContext().getELContext())  : null;
	}
	public void setOnNodeClick(java.lang.String _onNodeClick) {
		this._onNodeClick = _onNodeClick;
	}

	public boolean isExpanded() {
		if(_expanded != null )
			return _expanded;

		ValueExpression ve = getValueExpression("expanded");
		return ve != null ? (java.lang.Boolean) ve.getValue(getFacesContext().getELContext())  : false;
	}
	public void setExpanded(boolean _expanded) {
		this._expanded = _expanded;
	}

	public Object saveState(FacesContext context) {
		Object values[] = new Object[12];
		values[0] = super.saveState(context);
		values[1] = _widgetVar;
		values[2] = _value;
		values[3] = _toggleMode;
		values[4] = _cache;
		values[5] = _expandAnim;
		values[6] = _collapseAnim;
		values[7] = _nodeSelectListener;
		values[8] = _nodeExpandListener;
		values[9] = _nodeCollapseListener;
		values[10] = _onNodeClick;
		values[11] = _expanded;
		return ((Object) values);
	}
	public void restoreState(FacesContext context, Object state) {
		Object values[] = (Object[]) state;
		super.restoreState(context, values[0]);
		_widgetVar = (String) values[1];
		_value = (Object) values[2];
		_toggleMode = (String) values[3];
		_cache = (Boolean) values[4];
		_expandAnim = (String) values[5];
		_collapseAnim = (String) values[6];
		_nodeSelectListener = (MethodExpression) values[7];
		_nodeExpandListener = (MethodExpression) values[8];
		_nodeCollapseListener = (MethodExpression) values[9];
		_onNodeClick = (String) values[10];
		_expanded = (Boolean) values[11];
	}

	public void broadcast(javax.faces.event.FacesEvent event) throws javax.faces.event.AbortProcessingException {
		super.broadcast(event);
		
		FacesContext facesContext = FacesContext.getCurrentInstance();
		MethodExpression me = null;

		if(event instanceof NodeSelectEvent) {
			me = getNodeSelectListener();
		} else if(event instanceof NodeExpandEvent) {
			me = getNodeExpandListener();
		} else if(event instanceof NodeCollapseEvent) {
			me = getNodeCollapseListener();
		}
		
		if (me != null) {
			me.invoke(facesContext.getELContext(), new Object[] {event});
		}
	}

	protected FacesContext getFacesContext() {
		return FacesContext.getCurrentInstance();
	}

	protected ResourceHolder getResourceHolder() {
		FacesContext facesContext = getFacesContext();
		if(facesContext == null)
			return null;

		ValueExpression ve = facesContext.getApplication().getExpressionFactory().createValueExpression(facesContext.getELContext(), "#{primeFacesResourceHolder}", ResourceHolder.class);

		return (ResourceHolder) ve.getValue(facesContext.getELContext());
	}

	public void encodePartially(FacesContext facesContext) throws IOException {
		Renderer renderer = getRenderer(facesContext);

		if(renderer instanceof PartialRenderer) {
			((PartialRenderer)renderer).encodePartially(facesContext, this);
		}
	}
}